import 'package:flutter/material.dart';

class CustomErrorWidget extends StatelessWidget {
  final Function() onTap;
  final String errMsg;
  final String title;
  final TextStyle? messageTextStyle;
  final ErrorButtonStyle? errorButtonStyle;
  final double? spaceBetween;

  const CustomErrorWidget(
      {Key? key,
      required this.onTap,
      required this.title,
      required this.errMsg,
      required this.messageTextStyle,
      required this.errorButtonStyle,
      required this.spaceBetween})
      : super(key: key);

  /// Custom Error Widget to show the error message if there is something wrong with location when qiblah compass in used
  @override
  Widget build(BuildContext context) {
    return SizedBox(
      height: MediaQuery.of(context).size.height * 0.20,
      child: Padding(
        padding: const EdgeInsets.all(10),
        child: ListView(
          shrinkWrap: true,
          physics: const NeverScrollableScrollPhysics(),
          children: [
            Center(
              child: Text(
                textAlign: TextAlign.center,
                errMsg,
                style: messageTextStyle ?? const TextStyle(color: Colors.red),
              ),
            ),
            SizedBox(
              height: spaceBetween ?? 10,
            ),
            Center(
              child: SizedBox(
                width: errorButtonStyle?.buttonWidth,
                height: errorButtonStyle?.buttonHeight,
                child: MaterialButton(
                  color: errorButtonStyle?.buttonColor ?? Colors.grey.shade300,
                  textColor: errorButtonStyle?.textColor ?? Colors.black,
                  shape: RoundedRectangleBorder(
                      borderRadius: errorButtonStyle?.borderRadius ??
                          BorderRadius.circular(5)),
                  onPressed: onTap,
                  child: FittedBox(fit: BoxFit.scaleDown, child: Text(title)),
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }
}

/// for the decoration of button in error widget
class ErrorButtonStyle {
  BorderRadius? borderRadius;
  Color? buttonColor;
  Color? textColor;
  double? buttonHeight;
  double? buttonWidth;

  ErrorButtonStyle(
      {this.borderRadius,
      this.textColor,
      this.buttonColor,
      this.buttonHeight,
      this.buttonWidth});
}

/// for customizing error messages
class PermissionMessage {
  String? denied;
  String? permanentlyDenied;

  PermissionMessage({this.denied, this.permanentlyDenied});
}

/// for customizing error widget
class ErrorDecoration {
  ErrorButtonStyle? buttonStyle;
  PermissionMessage? permissionMessage;
  double? spaceBetween;
  TextStyle? messageTextStyle;

  ErrorDecoration(
      {this.buttonStyle,
      this.permissionMessage,
      this.spaceBetween,
      this.messageTextStyle});
}
